.. _cwlConformance:

CWL Conformance
===============

Note: To fully support `inplace_update`, ``--bypass-file-store`` should be enabled.
See :ref:`inplaceupdaterequirement`.

The badges below show Toil's support for different aspects of the CWL specification. They describe the current development version of Toil, not necessarily the release documented here.

CWL 1.2 Required Features
~~~~~~~~~~~~~~~~~~~~~~~~~

|required|

CWL 1.2 Optional Features
~~~~~~~~~~~~~~~~~~~~~~~~~

|command_line_tool|

|conditional|

|docker|

|expression_tool|

|format_checking|

|initial_work_dir|

|inline_javascript|

|inplace_update|

|input_object_requirements|

|json_schema_invalid|

|load_listing|

|multiple_input|

|networkaccess|

|resource|

|scatter|

|schema_def|

|step_input|

|timelimit|

|workflow|

|work_reuse|

.. |required| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/required.json%3Fjob=cwl_badge

.. |command_line_tool| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/command_line_tool.json%3Fjob=cwl_badge

.. |conditional| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/conditional.json%3Fjob=cwl_badge

.. |docker| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/docker.json%3Fjob=cwl_badge

.. |expression_tool| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/expression_tool.json%3Fjob=cwl_badge

.. |format_checking| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/format_checking.json%3Fjob=cwl_badge

.. |initial_work_dir| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/initial_work_dir.json%3Fjob=cwl_badge

.. |inline_javascript| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/inline_javascript.json%3Fjob=cwl_badge

.. |inplace_update| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/inplace_update.json%3Fjob=cwl_badge

.. |input_object_requirements| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/input_object_requirements.json%3Fjob=cwl_badge

.. |json_schema_invalid| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/json_schema_invalid.json%3Fjob=cwl_badge

.. |load_listing| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/load_listing.json%3Fjob=cwl_badge

.. |multiple_input| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/multiple_input.json%3Fjob=cwl_badge

.. |networkaccess| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/networkaccess.json%3Fjob=cwl_badge

.. |resource| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/resource.json%3Fjob=cwl_badge

.. |scatter| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/scatter.json%3Fjob=cwl_badge

.. |schema_def| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/schema_def.json%3Fjob=cwl_badge

.. |step_input| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/step_input.json%3Fjob=cwl_badge

.. |timelimit| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/timelimit.json%3Fjob=cwl_badge

.. |workflow| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/workflow.json%3Fjob=cwl_badge

.. |work_reuse| image:: https://flat.badgen.net/https/ucsc-ci.com/api/v4/projects/3/jobs/artifacts/master/raw/badges1.2/work_reuse.json%3Fjob=cwl_badge
